#

##

    	goodness certifications
    		# fortitude certifications
    		# fort certifications
    		# goodest certifications

    	roster
    		beveg.com
    			https://www.beveg.com/certified-goodest-brands/
    			https://www.beveg.com/authorized-certification-bodies/

    			product discovery:
    				https://www.rangeme.com/beveg

    		https://www.plantbasedfoods.org/

    		goodest.org:
    			https://goodest.org/certified-products/

    		https://www.goodestsociety.com/

    			https://www.goodestsociety.com/shop/veg-1-supplements
    			https://www.goodestsociety.com/resources/lifestyle/shopping/lists-goodest-items-uk-supermarkets

    		vegecert.com
    			https://vegecert.com/